//#include <iostream>
//#include <fstream>
#include <cstdio>
#include <cassert>
#include <ctime>
#include <cstring>

using namespace std;

const int MAX_NODES = 100000;

int adj[MAX_NODES];
int used[MAX_NODES];
int *adjNodes[MAX_NODES];
int adjNodeCount[MAX_NODES];

int peo[MAX_NODES];

struct dd
{
  int x;
  struct dd *next;
  struct dd *prev;

  dd(int info) : x(info) {}
};

struct dd *buckets[MAX_NODES]; // buckets[i] = linked list all nodes with degree i
struct dd *where[MAX_NODES]; // node i is here

int degree[MAX_NODES]; // what degree is node i
int oldbest = 0;

bool isEdge(int a, int b)
{
  for (int i = 0; i < adjNodeCount[a]; ++i) {
    if (adjNodes[a][i] == b) {
      return true;
    }
  }
  return false;
}

void init(int n)
{
  dd *old = 0;
  for (int i = 0; i < n; ++i) {
    degree[i] = 0;
    dd *t = new dd(i);
    where[i] = t;
    t->next = old;
    t->prev = 0;
    if (old) {
      old->prev = t;
    }
    old = t;
  }
  buckets[0] = old;
}

void delete_stuff(dd **list, dd *cell) {
  if (cell->prev == 0) {
    *list = cell->next;
    if (cell->next) {
      cell->next->prev = 0;
    }
  }
  else {
    cell->prev->next = cell->next;
    if (cell->next) {
      cell->next->prev = cell->prev;
    }
  }
  //  delete cell;
}

void add(int key)
{
  dd *d = new dd(key);
  where[key] = d;
  d->next = buckets[degree[key]];
  d->prev = 0;
  if (buckets[degree[key]]) {
    buckets[degree[key]]->prev = d;
    buckets[degree[key]] = d;
  }
  else {
    buckets[degree[key]] = d;
  }
}

void increase(int key)
{
  delete_stuff(&buckets[degree[key]], where[key]);
  degree[key]++;
  if (degree[key] > oldbest) {
    oldbest = degree[key];
  }
  add(key);
}

int best()
{
  while (!buckets[oldbest]) {
    oldbest--;
  }
  int result = buckets[oldbest]->x;
  delete_stuff(&buckets[oldbest], buckets[oldbest]);
  return result;
}

int nodeCount, edgeCount;

/*void printall()
{
  for (int i = 0; i < nodeCount; ++i) {
    if (buckets[i]) {
            cout << i << ": ";
      for (dd *s = buckets[i]; s; s = s->next) {
	cout << s->x << " ";
      }
      cout << endl;
    }
  }
}*/
  
int main()
{
  //  time_t start = clock();

  FILE *fi = fopen("tric.in", "r");
  FILE *fo = fopen("tric.out", "w");

  memset(adjNodeCount, 0, sizeof(adjNodeCount));

  fscanf(fi, "%d %d", &nodeCount, &edgeCount);
  for (int i = 0; i < edgeCount; ++i) {
    int a, b;
    fscanf(fi, "%d %d", &a, &b);
    adjNodeCount[a]++;
    adjNodeCount[b]++;
  }
  for (int i = 0; i < nodeCount; ++i) {
    adjNodes[i] = new int [adjNodeCount[i]];
  }
  memset(adjNodeCount, 0, sizeof(adjNodeCount));

  rewind(fi);
  fscanf(fi, "%d %d", &nodeCount, &edgeCount);
  for (int i = 0; i < edgeCount; ++i) {
    int a, b;
    fscanf(fi, "%d %d", &a, &b);
    adjNodes[a][adjNodeCount[a]++] = b;
    adjNodes[b][adjNodeCount[b]++] = a;
  }

  //  time_t end = clock();

  //  printf("read time: %.4lf", (double)(end - start) / CLOCKS_PER_SEC);

  init(nodeCount);
  memset(adj, 0, sizeof(adj));
  memset(used, 0, sizeof(used));

  long long result = 0;
  for (int i = nodeCount - 1; i >= 0; --i) {
    int bestNode = best();
    peo[i] = bestNode;
    used[bestNode] = 1;
    //    cout << "bestNode " << bestNode << endl;
    //    printall();

    /*    for (int j = 0; j < adjNodeCount[bestNode]; ++j) {
	  for (int k = j + 1; k < adjNodeCount[bestNode]; ++k) {
      if (!used[adjNodes[bestNode][j]] || !used[adjNodes[bestNode][k]])
	continue;
	  if (!isEdge(adjNodes[bestNode][j], adjNodes[bestNode][k])) {
	//	  printf("belea ca focu %d %d\n", adjNodes[bestNode][j], adjNodes[bestNode][k]);
	//	  exit(0);
	  }
	}
      }*/

    int count = 0;
    for (int j = 0; j < adjNodeCount[bestNode]; ++j) {
      int toInc = adjNodes[bestNode][j];
      if (!used[toInc]) {
	increase(toInc);
      }
      else {
	count++;
      }
    }
    result += (count - 1) * count / 2;
  }

  fprintf(fo, "%lld\n", result);
  fclose(fi);
  fclose(fo);
}
